"""
Views for ResumeManagerCore app.
"""

# Third-Party Imports.
from django.db.models import Q
from django.contrib.auth import get_user_model
from django.contrib.auth.mixins import LoginRequiredMixin
from django.shortcuts import render
from django.views.generic import ListView, UpdateView

# Internal Imports.
from .models import Resume


class Index(LoginRequiredMixin, ListView):
    """Base view for ResumeManager index."""

    model = Resume
    template_name = 'resume_manager/index.html'
    context_object_name = 'resumes'

    def get_queryset(self):
        """Get "main" list of objects for template display."""

        # Return only resumes that are under example user or current user.
        example_user = get_user_model().objects.get(username='example_user')
        resumes = Resume.objects.filter(user__in=[example_user, self.request.user])

        print('\n\n\n\n')
        print('pulled resumes:')
        print('{0}'.format(resumes))
        print('\n')
        print('all resumes:')
        print('{0}'.format(Resume.objects.all()))
        print('\n\n\n\n')

        return resumes
